==> zio-aws-kinesisanalytics_2.13-5.17.129.2-sources.jar: zio/aws/kinesisanalytics/model/InputProcessingConfigurationDescription.scala <==
package zio.aws.kinesisanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class InputProcessingConfigurationDescription(
    inputLambdaProcessorDescription: Option[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription = {
    import InputProcessingConfigurationDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
      .builder()
      .optionallyWith(
        inputLambdaProcessorDescription.map(value => value.buildAwsValue())
      )(_.inputLambdaProcessorDescription)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly =
    zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription
      .wrap(buildAwsValue())
}
object InputProcessingConfigurationDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription =
      zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription(
        inputLambdaProcessorDescription.map(value => value.asEditable)
      )
    def inputLambdaProcessorDescription: Option[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ]
    def getInputLambdaProcessorDescription: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "inputLambdaProcessorDescription",
      inputLambdaProcessorDescription
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ) extends zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly {
    override val inputLambdaProcessorDescription: Option[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ] = scala
      .Option(impl.inputLambdaProcessorDescription())
      .map(value =>
        zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ): zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-kinesisanalytics_2.13-6.20.103.1-sources.jar: zio/aws/kinesisanalytics/model/InputProcessingConfigurationDescription.scala <==
package zio.aws.kinesisanalytics.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class InputProcessingConfigurationDescription(
    inputLambdaProcessorDescription: Optional[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription = {
    import InputProcessingConfigurationDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
      .builder()
      .optionallyWith(
        inputLambdaProcessorDescription.map(value => value.buildAwsValue())
      )(_.inputLambdaProcessorDescription)
      .build()
  }
  def asReadOnly
      : zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly =
    zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription
      .wrap(buildAwsValue())
}
object InputProcessingConfigurationDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription =
      zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription(
        inputLambdaProcessorDescription.map(value => value.asEditable)
      )
    def inputLambdaProcessorDescription: Optional[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ]
    def getInputLambdaProcessorDescription: ZIO[
      Any,
      AwsError,
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "inputLambdaProcessorDescription",
      inputLambdaProcessorDescription
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ) extends zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly {
    override val inputLambdaProcessorDescription: Optional[
      zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.inputLambdaProcessorDescription())
      .map(value =>
        zio.aws.kinesisanalytics.model.InputLambdaProcessorDescription
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.kinesisanalytics.model.InputProcessingConfigurationDescription
  ): zio.aws.kinesisanalytics.model.InputProcessingConfigurationDescription.ReadOnly =
    new Wrapper(impl)
}
